function [YearFuelCon,NoContainer,MCR,Penalty] = FuelCon(TradeSpace,EpochSpace)
%Estimates the operational profile and fuel consumption based
%on the liner companies demand and design variables 

YearFuelCon = zeros(length(EpochSpace),length(TradeSpace));
NoContainer = zeros(length(EpochSpace),length(TradeSpace));
MCR = zeros(length(EpochSpace),length(TradeSpace));
Penalty = zeros(length(EpochSpace),length(TradeSpace));

for i=1:length(EpochSpace)
    SpeedProfile = zeros(30,1);
    avg = round(EpochSpace(i,10)); %avg speed on trade 
    if EpochSpace(i,7) == 12000
        PortCalls = 13;
    elseif EpochSpace(i,7) == 7000
        PortCalls = 4;
    elseif EpochSpace(i,7) == 4000
        PortCalls = 7;
    end 
    
    TransitTime = ((EpochSpace(i,7))*2)/(avg); %Roundtrip time in hours 
    
    %Hours per trip av various speeds (Transit)
    SpeedProfile(avg-3) = 0.05*TransitTime;
    SpeedProfile(avg-2) = 0.10*TransitTime;
    SpeedProfile(avg-1) = 0.15*TransitTime;
    SpeedProfile(avg) = 0.4*TransitTime;
    SpeedProfile(avg+1) = 0.15*TransitTime;
    SpeedProfile(avg+2) = 0.10*TransitTime;
    SpeedProfile(avg+3) = 0.05*TransitTime; 
    
    %Maneouvering time in port 
    PortTimeMan =PortCalls*2*8; %8 hour per port, roundtrip 
    
    %Speed Profile Port Maneouvering 
    SpeedProfile(12) = SpeedProfile(12) + 0.125*PortTimeMan;
    SpeedProfile(11) = SpeedProfile(11) + 0.125*PortTimeMan;  
    SpeedProfile(10) = SpeedProfile(10) + 0.125*PortTimeMan;
    SpeedProfile(9) = SpeedProfile(9) + 0.125*PortTimeMan;
    SpeedProfile(8) = SpeedProfile(8) + 0.125*PortTimeMan;
    SpeedProfile(7) = SpeedProfile(7) + 0.125*PortTimeMan;
    SpeedProfile(6) = SpeedProfile(6) + 0.125*PortTimeMan;
    SpeedProfile(5) = SpeedProfile(5) + 0.125*PortTimeMan;
    
    
    for j=1:length(TradeSpace)
        
        %Number of containers per trip, based on demand from liner
        %companies and ship capacity
        if EpochSpace(i,11) >= TradeSpace(j,1)
            NoContainer(i,j) = TradeSpace(j,1);
            Penalty(i,j) = EpochSpace(i,11)-TradeSpace(j,1);
        else 
            NoContainer(i,j) = EpochSpace(i,11);
        end
            
        PortTimeLoading = (NoContainer(i,j)*1.2)/200; %0.8 tilization one way, 0.4 other way. 200 containers per hour at port; 
        
        FuelConTrip = 0;
        HoursYear = 8520; %10 days off-hire 
        RoundTripsYear = HoursYear/(TransitTime+PortTimeLoading+PortTimeMan);
        NoContainer(i,j)=NoContainer(i,j)*RoundTripsYear;
        
        for k=1:length(SpeedProfile)

            if SpeedProfile(k) == 0 
                continue %Skip to next iteration 
            end
            
            KW = TradeSpace(j,6)*0.7*((k/(TradeSpace(j,4)))^3);
            MCR(i,j) = (KW/TradeSpace(j,6))*100;
            kWh = KW*SpeedProfile(k);
            
            FuelConTrip = FuelConTrip + kWh*((0.0068*MCR(i,j)^2)-(0.9519*MCR(i,j))+201.3)*(1/1000000);
            
        end
        YearFuelCon(i,j) =  FuelConTrip*RoundTripsYear;
    end
    
end
