%This function calculates and plots the annual tranportation capacity,
%total cost and profit based on economc production theory
%Inputs
L = 0.6; %Utilization factor 
Tw = 2; %Waiting time per roundtrip
D = 5000*2; %Distance one way (*2 for roundtrip)
Rh = 300; %Unlaoding rate, containers / hour 
OH=10; %Days off-hire during one year
SFC=0.000180;
FP = 350; % 350 USD/tonne for fuel
CRF = 0.15; 
UnitRevenue = 0.000200; %100 USD/TEU; 

V=[10:1:30]; %Range of speed to consider
q=[1000:1000:25000]; %Range of capacitues to consider 

Capex = zeros(length(V),length(q)); 
Q = zeros(length(V),length(q));
C = zeros(length(V),length(q));
P = zeros(length(V),length(q));
CF = zeros(length(V),length(q));
YearlyCost = zeros(length(V),length(q));
FuelCon = zeros(length(V),length(q));
R = zeros(length(V),length(q));

%loops through the designspace 
for i=1:length(V)
    for j=1:length(q)
        TS = (D/(V(i)*24));
        TP = ((q(j)*L)/(12*Rh)); 
        T = TS + TP + Tw; 
        Q(i,j) = (2*q(j)*L*(365-OH))/(((q(j)*L)/ ...
        (12*Rh))+(D/(V(i)*24))+(Tw)); 
        P(i,j) = 1.637*(q(j)^0.48)*((V(i)/20)^3)*(1/(SFC*24));
        Capex(i,j) = 0.000350*P(i,j)+15+0.0069*q(j); %mUSD
        FuelCon(i,j) = P(i,j)*SFC*(TS/T)*24*(365-OH); 
        CF(i,j) = FuelCon(i,j)*FP*(1/1000000); 
        YearlyCost(i,j) = Capex(i,j)*CRF + CF(i,j); 
        R(i,j) = UnitRevenue*Q(i,j) - YearlyCost(i,j);
    end
end

%Plotting
figure(1)
[F,t] = contour(q,V,Q,10)
title('Isoquants')
xlabel('q [TEU]')
ylabel('V[kn]')

figure(2)
[X Y] = meshgrid(q,V);
surf(X,Y,Q)
title('3D surface plot (Transportation Capacity)')
xlabel('q [TEU]')
ylabel('V[kn]')

figure(3)
[F,t] = contour(q,V,YearlyCost,10)
title('ISOCOST')
xlabel('q [TEU]')
ylabel('V[kn]')

figure(4)
[F,t] = contour(q,V,R,10)
title('Revenue')
xlabel('q [TEU]')
ylabel('V[kn]')

figure(5)
[X Y] = meshgrid(q,V);
surf(X,Y,R)
title('3D surface plot')
xlabel('q [TEU]')
ylabel('V[kn]')
